@@ -67,93 +67,6 @@ class MasterDataModel(models.Model):
     def __str__(self) -> str:
         return self.name
 
-NAME_PREFIX_CHOICES = [
-    ('junior', _('Junior')),
-    ('senior', _('Senior')),
-    ('doctor', _('Doctor')),
-    ('professor', _('Professor')),
-    ('widow', _('Widow')),
-]
-
-class PersonRegistratNameMixin(models.Model):
-
-    class Meta:
-        abstract = True
-
-    name_prefix = models.CharField(
-        verbose_name=_('name prefix'),
-        max_length=10,
-        choices=NAME_PREFIX_CHOICES,
-        default=None,
-        blank=True,
-        null=True
-    )
-
-    first_name = models.CharField(
-        verbose_name=_('first name'),
-        max_length=100,
-        blank=False,
-        null=False
-    )
-
-    middle_name = models.CharField(
-        verbose_name=_('middle name'),
-        max_length=100,
-        default=None,
-        blank=True,
-        null=True
-    )
-
-    last_name = models.CharField(
-        verbose_name=_('last name'),
-        max_length=100,
-        blank=False,
-        null=False
-    )
-
-    name_suffix = models.CharField(
-        verbose_name=_('name suffix'),
-        max_length=10,
-        default=None,
-        blank=True,
-        null=True
-    )
-
-    @property
-    def full_name(self):
-        return "{prefix} {first} {middle} {last} {suffix}".format(
-            prefix=str(self.name_prefix) if self.name_prefix is not None else '',
-            suffix=str(self.name_suffix) if self.name_suffix is not None else '',
-            first=str(self.first_name) if self.first_name is not None else '',
-            middle=str(self.middle_name) if self.middle_name is not None else '',
-            last=str(self.last_name if self.last_name is not None else '')
-        ).title()
-
-class PersonBirthDataMixin(models.Model):
-
-    class Meta:
-        abstract = True
-
-    birthdate = models.DateField(
-        verbose_name=_('birth date'),
-        blank=False,
-        null=False,
-    )
-
-    birthplace = models.CharField(
-        verbose_name=_('birth place'),
-        max_length=200,
-        blank=False,
-        null=False
-    )
-
-    name_of_mother = models.CharField(
-        verbose_name=_('name of mother'),
-        max_length=200,
-        default=None,
-        blank=False,
-        null=False
-    )
 
 
 gender_female = 'female'
@@ -163,34 +76,6 @@ gender_choices = [
     (gender_male, _('Male')),
 ]
 
-class TaxationModelMixin(models.Model):
-
-    class Meta:
-        abstract = True
-
-    tax_number = models.CharField(
-        verbose_name=_('tax number'),
-        max_length=100
-    )
-
-
-class NationalityModelMixin(models.Model):
-    class Meta:
-        abstract = True
-
-    primary = models.CharField(
-        verbose_name=_('nationality'),
-        max_length=100
-    )
-
-    inland_resident = models.BooleanField(
-        verbose_name=_('has inland residence'),
-        help_text=_('Has inland address.'),
-        blank=False,
-        null=False,
-        default=True
-    )
-
 
 class SubAccount(BankAccountModelMixin):
 
@@ -298,60 +183,6 @@ class RecreationalCardModelMixin(models.Model):
 
 
 
-class PersonModelManager(models.Manager):
-    pass
-
-class PersonModel(PersonBirthDataMixin, PersonRegistratNameMixin, NationalityModelMixin, TaxationModelMixin, MasterDataModel):
-
-    class Meta:
-        verbose_name = _('person')
-        verbose_name_plural = _('people')
-
-    objects = PersonModelManager
-
-    gender = models.CharField(
-        verbose_name=_('gender'),
-        choices=gender_choices,
-        max_length=10,
-        default=None,
-        blank=True,
-        null=True,
-    )
-
-    permanent_address = AddressField(
-        verbose_name=_('permanent address'),
-        help_text=_('Permanent address, desc.'),
-        related_name='permanent_residents',
-        blank=False,
-        null=False,
-        on_delete=models.CASCADE
-    )
-
-    temporary_address = AddressField(
-        verbose_name=_('temporary address'),
-        help_text=_('temporary address, desc.'),
-        related_name='termorary_residents',
-        blank=True,
-        null=True,
-        default=None,
-        on_delete=models.CASCADE
-    )
-
-    phone_number = PhoneNumberField(
-        verbose_name=_('phone number'),
-        help_text=_('Phone number, desc.'),
-        blank=False,
-        null=False,
-    )
-
-    email = models.EmailField(
-        verbose_name=_('email'),
-        help_text=_('Primary email address')
-    )
-
-    def __str__(self):
-        return str(self.full_name)
-
 class EnvironmentalClassificationModel(MasterDataModel):
 
     class Meta:
@@ -395,6 +226,7 @@ class PretenceModel(MasterDataModel):
     """
 
     class Meta:
+        db_table = "legal_pretences"
         verbose_name = _('Pretence')
         verbose_name_plural = _('Pretences')
 
@@ -404,12 +236,182 @@ class LegalRelationshipModel(MasterDataModel):
     """
 
     class Meta:
+        db_table = "legal_relationships"
         verbose_name = _('Legal relationship')
         verbose_name_plural = _('Legal relationships')
 
-class OrganizationModel(MasterDataModel):
+class PersonNamePrefixModel(models.Model):
 
     class Meta:
+        db_table = "name_prefixes"
+        verbose_name = _('Person name prefix')
+        verbose_name_plural = _('Person name prefixes')
+
+    value = models.CharField(
+        verbose_name=_('value'),
+        max_length=100,
+        default=None,
+        blank=False,
+        null=False
+    )
+
+class CustomerModel(MasterDataModel):
+
+    class Meta:
+        db_table = "customers"
+        verbose_name = _('customer')
+        verbose_name_plural = _('customers')
+        abstract = True
+
+class PersonModelManager(models.Manager):
+    pass
+
+class PersonModel(CustomerModel):
+
+    class Meta:
+        db_table = "persons"
+        verbose_name = _('person')
+        verbose_name_plural = _('people')
+
+    objects = PersonModelManager
+
+    gender = models.CharField(
+        verbose_name=_('gender'),
+        choices=gender_choices,
+        max_length=10,
+        default=None,
+        blank=True,
+        null=True,
+    )
+
+    birthdate = models.DateField(
+        verbose_name=_('birth date'),
+        blank=False,
+        null=False,
+    )
+
+    birthplace = models.CharField(
+        verbose_name=_('birth place'),
+        max_length=200,
+        blank=False,
+        null=False
+    )
+
+    name_of_mother = models.CharField(
+        verbose_name=_('name of mother'),
+        max_length=200,
+        default=None,
+        blank=False,
+        null=False
+    )
+
+    name_prefix = models.ForeignKey(
+        to=PersonNamePrefixModel,
+        verbose_name=_('name prefix'),
+        related_name='persons',
+        on_delete=models.CASCADE,
+        default=None,
+        blank=True,
+        null=True
+    )
+
+    first_name = models.CharField(
+        verbose_name=_('first name'),
+        max_length=100,
+        blank=False,
+        null=False
+    )
+
+    middle_name = models.CharField(
+        verbose_name=_('middle name'),
+        max_length=100,
+        default=None,
+        blank=True,
+        null=True
+    )
+
+    last_name = models.CharField(
+        verbose_name=_('last name'),
+        max_length=100,
+        blank=False,
+        null=False
+    )
+
+    name_suffix = models.CharField(
+        verbose_name=_('name suffix'),
+        max_length=10,
+        default=None,
+        blank=True,
+        null=True
+    )
+
+    permanent_address = AddressField(
+        verbose_name=_('permanent address'),
+        help_text=_('Permanent address, desc.'),
+        related_name='permanent_residents',
+        blank=False,
+        null=False,
+        on_delete=models.CASCADE
+    )
+
+    temporary_address = AddressField(
+        verbose_name=_('temporary address'),
+        help_text=_('temporary address, desc.'),
+        related_name='termorary_residents',
+        blank=True,
+        null=True,
+        default=None,
+        on_delete=models.CASCADE
+    )
+
+    phone_number = PhoneNumberField(
+        verbose_name=_('phone number'),
+        help_text=_('Phone number, desc.'),
+        blank=False,
+        null=False,
+    )
+
+    email = models.EmailField(
+        verbose_name=_('email'),
+        help_text=_('Primary email address')
+    )
+
+    primary = models.CharField(
+        verbose_name=_('nationality'),
+        max_length=100
+    )
+
+    inland_resident = models.BooleanField(
+        verbose_name=_('has inland residence'),
+        help_text=_('Has inland address.'),
+        blank=False,
+        null=False,
+        default=True
+    )
+
+    tax_number = models.CharField(
+        verbose_name=_('tax number'),
+        max_length=100
+    )
+
+    @property
+    def full_name(self):
+        return "{prefix} {first} {middle} {last} {suffix}".format(
+            prefix=str(self.name_prefix) if self.name_prefix is not None else '',
+            suffix=str(self.name_suffix) if self.name_suffix is not None else '',
+            first=str(self.first_name) if self.first_name is not None else '',
+            middle=str(self.middle_name) if self.middle_name is not None else '',
+            last=str(self.last_name if self.last_name is not None else '')
+        ).title()
+
+    def __str__(self):
+        return str(self.full_name)
+
+
+class OrganizationModel(CustomerModel):
+
+    class Meta:
+        db_table = "organizations"
         verbose_name = _('organization')
         verbose_name_plural = _('organizations')
 
